/*
www.E2CRE8.be - Brainbox Arduino  - by Bart Huyskens
04/01/2016

This program is used to demonstrate how Analog inputs work with an ARduino platform
An ARduino uC is a normal AVR microcontroller but is not programmed that way.
The absense of port programming makes that we can't output a certain analog value to 8 leds or so.

The microcontroller will read the analog voltage at pin A0 and 
will convert it into a digital 10 bit value between 0-1024

What we can do with an ARduino to somehow visualise this analog value is to:
- output the analog value as a PWM (AnalogWrite) to a led -> we use the BLUE led at pin 13
- Convert the Analog value into a hearable sound and use the buzzer in pin 7 for this
- Send this analog Value via the USB cable back to our computer and use the Serial monitor 
  of the ARduino IDE to visualise this value

We will demonstrate these 3 methods in this program
  
 The circuit:
 * potentiometer connected to analog pin 0.
   Center pin of the potentiometer goes to the analog pin.
   side pins of the potentiometer go to +5V and ground
 * BLUE LED connected from digital pin 13
 * Buzzer connected to pin 7

 */

// These constants won't change.  They're used to give names
// to the pins used:
const int analogInPin = A0;   // Analog input pin that the potentiometer is attached to
const int analogOutPin = 13;  // Analog output pin that the BLUE LED is attached to
const int BuzzerPin = 7;      // the buzzer on the Brainbox ARduino is connected to pin 7

int sensorValue = 0;        // value read from the analog input - set to 0 to start
int outputValue = 0;        // value output to the PWM (analog out)- set to 0 to start

void setup() {
  // initialize serial communications at 9600 bps:
  Serial.begin(9600);
}

void loop() {
          // read the analog in value:
  sensorValue = analogRead(analogInPin);
         
          // map it to the range of the analog out:
          // sensorvalue is a value between 0 and 1024 (10 bit AD)
          // PWM or ANalogWrite can only work with values bewteen 0 and 255 (8bit)
  outputValue = map(sensorValue, 0, 1023, 0, 255);
          
          // change the analog out value:
          // generates a PWM signal on a pin with a duty cycle between 0-255 (0-100%)
  analogWrite(analogOutPin, outputValue);

          // print the results to the serial monitor:
          // Open the serial monitor of the arduino IDE to see the result
  Serial.print("sensor = " );
  Serial.print(sensorValue);
  Serial.print("\t output = ");
  Serial.println(outputValue);

          // the buzzer converts the sensorvalue into hearable
          // frequencies. The sensorValue is a value between 0-1024
          // but the lowest frequency that is recognizable as a tone is 
          // +/- 20Hz. That is why we add 20Hz teh SensorValue.
  tone (BuzzerPin, sensorValue+20);

          // wait 2 milliseconds before the next loop
          // for the analog-to-digital converter to settle
          // after the last reading:
  delay(2);
}
